# Architecture Decision Records

This directory contains Architecture Decision Records (ADRs) for Local Brain.

| ADR | Title | Status | Date |
|-----|-------|--------|------|
| [ADR-001](./001-custom-implementation.md) | Keep Custom Implementation over Frameworks | Accepted | 2025-12-08 |
| [ADR-002](./002-smolagents.md) | Use Smolagents for Code Execution | Accepted | 2025-12-09 |
| [ADR-003](./003-no-web-tools.md) | No Web Tools | Accepted | 2025-12-08 |

## What is an ADR?

An Architecture Decision Record captures an important architectural decision made along with its context and consequences.

## Template

```markdown
# ADR-NNN: Title

**Status:** Proposed | Accepted | Deprecated | Superseded  
**Date:** YYYY-MM-DD

## Context
What is the issue we're facing?

## Decision
What have we decided to do?

## Consequences
What are the results of this decision?
```

